package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````<"(```````!``````````"BQ````
M`````````$``.``-`$``&0`8``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````%@:````````6!H`````````
M$`````````$````%`````"``````````(``````````@````````03P`````
M``!!/``````````0`````````0````0`````8`````````!@`````````&``
M``````!@1@```````&!&`````````!`````````!````!@```/"K````````
M\+L```````#PNP```````#`$````````<!0`````````$`````````(````&
M`````*P`````````O`````````"\````````T`$```````#0`0````````@`
M````````!`````0````X`P```````#@#````````.`,```````!0````````
M`%``````````"``````````$````!````(@#````````B`,```````"(`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````4`````````!0``````````@`````````4.5T9`0`
M``!PGP```````'"?````````<)\```````#<`````````-P`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````\*L```````#PNP```````/"[````
M````$`0````````0!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````0`````4```!'3E4``@``P`0````#````````
M``*``,`$`````0`````````!``'`!`````D``````````@`!P`0````!````
M``````0````4`````P```$=.50!Y`5JAX;*VA?V:#@&(+2%K)+Y#"P0````0
M`````0```$=.50``````!`````0``````````````"L```!%````!`````@`
M```@$!``!4`$A"@"``2`A@"$@@D```D@!`B(@!!!N@`""$4`````````````
M`$8``````````````$<``````````````$@`````````20````````!+````
M``````````!,````30````````!.````3P```%$`````````4@```%,```!4
M``````````````````````````````!5````5@```%<```!8````60``````
M````````6P````````!<``````````````")!W#3:QJ>4*/@^TGC1\8!9J_,
M9D-%U>R[XY)\LP&+;V_%WQ\5C"7,+L6;MFL)0]8A_^0.^Z%L8,/E/RP-.I<+
MS]Y'+=EQ6!Q_J9R;X:<""D+ZUX=K?YI\,V+;[=1DU'RM2^/`````````````
M````````````````````(@(``!(`````````````````````````N`(``!(`
M````````````````````````Z````!$`````````````````````````F@$`
M`!(`````````````````````````H@(``!(`````````````````````````
MC````!$`````````````````````````"0(``!(`````````````````````
M````/`$``!(`````````````````````````@`(``!(`````````````````
M````````Q0$``!(``````````````````````````0```"``````````````
M````````````70(``!(`````````````````````````9P```!(`````````
M````````````````G0(``!(`````````````````````````E````!(`````
M`````````````````````@(``!(`````````````````````````5`(``!(`
M````````````````````````J`(``!(`````````````````````````T@``
M`!(`````````````````````````X@```!(`````````````````````````
M4@$``!(`````````````````````````<`$``!(`````````````````````
M````B@```!$`````````````````````````>@,``!(`````````````````
M````````$````"``````````````````````````.@(``!(`````````````
M````````````)P(``!(`````````````````````````O0```!(`````````
M````````````````+````"``````````````````````````G0```!(`````
M````````````````````JP```!(`````````````````````````+`(``!(`
M````````````````````````1@```"(`````````````````````````!P$`
M`!(`````````````````````````V`$``!(`````````````````````````
M(@$``!(`````````````````````````10(``!(`````````````````````
M````C@(``!(`````````````````````````KP$``!(`````````````````
M````````0P$``!(`````````````````````````,P$``!(`````````````
M````````````8`$``!(`````````````````````````?@$``!(`````````
M````````````````%`(``!(`````````````````````````:`(``!(`````
M````````````````````A0$``!(`````````````````````````V0(``!(`
M````````````````````````>0```!(`````````````````````````DP$`
M`!(`````````````````````````C`$``!(`````````````````````````
MG````!(`````````````````````````J`$``!(`````````````````````
M````\P```!(`````````````````````````Q`(``!(`````````````````
M````````]@$``!(`````````````````````````E0(``!(`````````````
M````````````V0```!(`````````````````````````Q````!(`````````
M````````````````>0(``!$`````````````````````````Z0$``!$`````
M````````````````````I````!(`````````````````````````:`$``!(`
M````````````````````````%P$``!(`````````````````````````M@$`
M`!(`````````````````````````50```!(`````````````````````````
M=P$``!(`````````````````````````LP```!(`````````````````````
M````8@(``!(`````````````````````````"P0``!$`%0`8P`````````@`
M````````7@,``!(`#`#03@```````.L!````````%00``!(`#`"@1```````
M`$<%````````"P,``!(`#`"00P```````"4`````````4@,``!(`#`#`0P``
M`````-T`````````Y0,``!``%0`@P```````````````````TP,``!``%@!@
MT```````````````````+@,``!(`#`#P20```````'T`````````@P,``!(`
M#``03`````````<!````````R@,``!(`#`"P2P```````%D`````````^@(`
M`!(`#`!@00````````H`````````G@,``!``%0``P```````````````````
M_@,``!(`#`!P00```````!4"````````[`,``!(`#`"@2@```````!`!````
M````M@,``!(`#`!`0````````#D`````````H`,``"``%0``P```````````
M````````V`,``!(`#`#`4````````,\(````````O@,``!``%@`@P```````
M````````````:`,``!(`#`!P2@```````",`````````/`,``!(`#`"`0```
M`````-X`````````JP,``!(`#``@30```````*<!````````8@```!(`#``@
M(````````$4"````````I`,``!(`#`!P(@```````"8`````````&`,``!(`
M#`"060```````(4"````````CP,``!$`#@``8`````````0``````````%]?
M9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-
M7W)E9VES=&5R5$U#;&]N951A8FQE`%]?8WAA7V9I;F%L:7IE`%]?;&EB8U]S
M=&%R=%]M86EN`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V9A:6P`
M7U]E;G9I<F]N`'-T<FYC;7``;'-T870V-`!A8V-E<W,`;W!E;F1I<@!R96%D
M9&ER-C0`<W1R;&5N`%]?<W!R:6YT9E]C:&L`=6YL:6YK`&-L;W-E9&ER`')M
M9&ER`%!,7W1H<E]K97D`<'1H<F5A9%]G971S<&5C:69I8P!B;V]T7T1Y;F%,
M;V%D97(`4&5R;%]N97=84P!097)L7VYE=UA37V9L86=S`')E861L:6YK`&UE
M;6-H<@!097)L7W-V7W-E='!V;@!097)L7W-V7W-E='!V`&UE;6UO=F4`<F5A
M;&QO8P!G971P:60`;65M8W!Y`'-T<F-H<@!S=')D=7``<W1R=&]K`'-T<F-M
M<`!?7W-T<FYC<'E?8VAK`&=E='5I9`!S=')S='(`4&5R;%]S>7-?:6YI=#,`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?871F;W)K7VQO8VL`4$Q?9&]?=6YD
M=6UP`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7W!A<G-E`'!E<FQ?9&5S=')U
M8W0`<&5R;%]F<F5E`%!E<FQ?<WES7W1E<FT`<&5R;%]A;&QO8P!P97)L7V-O
M;G-T<G5C=`!P97)L7W)U;@!E>&ET`&UK9&ER`%]?97)R;F]?;&]C871I;VX`
M<W1D97)R`%]?9G!R:6YT9E]C:&L`;W!E;C8T`&QS965K-C0`<F5A9`!C;&]S
M90!097)L7V=V7V9E=&-H<'8`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O
M;G1E>'0`4&5R;%]M9U]S970`;&EB<&5R;"YS;P!L:6)C+G-O+C8`<&%R7V-U
M<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4
M`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N
M86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?
M8VQE86YU<`!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?<W1A<G0`<VAA7W5P9&%T
M90!X<U]I;FET`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R7VUK=&UP
M9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?
M<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R+C$T`$=,24)#7S(N,S0`1TQ)
M0D-?,BXT`$=,24)#7S(N,S,`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXR+C4`1TQ)
M0D-?,BXS+C0`+W5S<B]L:6(O<&5R;#4O-2XS-"]C;W)E7W!E<FPO0T]210``
M``$``0`!``(``P`#``$``P`"``$``0`#``0``P`#``,``0`!``,``P`!``,`
M`P`#``$``0`#``,``0`%``,``0`#``$``0`!``$``P`#``$``P`#``,``0`#
M``,``0`&``,``P`%``,`!P`!``$``P`#``(``P`!``,``P`!``$`!P`(``,`
M`P`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$`!P#P`@``$`````````"4D98&```(`"($```0````M)&6!@``
M!P`M!```$````!1I:0T```8`.`0``!````"SD98&```%`$($```0````<AEI
M"0``!`!-!```$````'4::0D```,`600``!````!T&6D)```"`&4$````````
M\+L````````(`````````&`C````````^+L````````(`````````!`C````
M````",`````````(``````````C`````````&,`````````(`````````.!B
M````````Z+T````````&`````0``````````````\+T````````&`````@``
M````````````^+T````````&`````P```````````````+X````````&````
M!```````````````"+X````````&````!0``````````````$+X````````&
M````!@``````````````&+X````````&````!P``````````````(+X`````
M```&````"```````````````*+X````````&````"0``````````````,+X`
M```````&````"@``````````````.+X````````&````"P``````````````
M0+X````````&````#```````````````2+X````````&````#0``````````
M````4+X````````&````#@``````````````6+X````````&````#P``````
M````````8+X````````&````$```````````````:+X````````&````$0``
M````````````<+X````````&````$@``````````````>+X````````&````
M$P``````````````@+X````````&````%```````````````B+X````````&
M````%0``````````````D+X````````&````%@``````````````F+X`````
M```&````&```````````````H+X````````&````&0``````````````J+X`
M```````&````&@``````````````L+X````````&````&P``````````````
MN+X````````&````'```````````````P+X````````&````'0``````````
M````R+X````````&````'@``````````````T+X````````&````'P``````
M````````V+X````````&````(```````````````X+X````````&````(0``
M````````````Z+X````````&````(@``````````````\+X````````&````
M(P``````````````^+X````````&````)````````````````+\````````&
M````)0``````````````"+\````````&````)@``````````````$+\`````
M```&````)P``````````````&+\````````&````*```````````````(+\`
M```````&````*0``````````````*+\````````&````*@``````````````
M,+\````````&````*P``````````````.+\````````&````+```````````
M````0+\````````&````+0``````````````2+\````````&````+@``````
M````````4+\````````&````+P``````````````6+\````````&````,```
M````````````8+\````````&````,0``````````````:+\````````&````
M,@``````````````<+\````````&````,P``````````````>+\````````&
M````-```````````````@+\````````&````-0``````````````B+\`````
M```&````-@``````````````D+\````````&````-P``````````````F+\`
M```````&````.```````````````H+\````````&````.0``````````````
MJ+\````````&````.@``````````````L+\````````&````.P``````````
M````N+\````````&````/```````````````P+\````````&````/0``````
M````````R+\````````&````/@``````````````T+\````````&````/P``
M````````````V+\````````&````0```````````````X+\````````&````
M00``````````````Z+\````````&````0@``````````````\+\````````&
M````0P``````````````^+\````````&````1```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!2F>``!(A<!T`O_02(/$",,``````/,/'OI!5%5(@^PX
MB7PD'$B-?"0<2(ET)!!(C70D$$B)5"0(2(U4)`AD2(L$)2@```!(B40D*#'`
M_Q5ZGP``2(LURYT``$B+/82>``!(B?)GZ*L[``!(BP4\GP``@#@`#X0]`0``
M3(LE;)T``$&+/"3_%>J>``!!BSPD@(@J!````O\5V9X``("(*@0```&+1"0<
MC7@$1(U@`TAC_TC!YP/_%<J>``!(BTPD$(MT)!Q)B<%(B05_GP``2(L!28D!
M2(T%6$```$F)00A(C04GGP``2(L`28E!$$B-!4)```!)B4$8@_X!#XX^`0``
M2(/!"(/&`[@$````#Q^$``````!(BSE(8]"#P`%(@\$(28D\T3G&=>M(8_9$
MB>)(BST&GP``13'`2<<$\0````!,B<E(C34Y&P``_Q6[G```08G$A<`/A)(`
M``!(C6PD)$B+/=2>``#_%;Z=```QP$B)[DB-/1T_``#H)1@``$B%P'1_2(L]
ML9X``/\52YP``/\5-9T``$B+1"0H9$@K!"4H````#X6H````2(/$.$2)X%U!
M7,/_%>"<``!(B05YG@``2(G'2(7`='W_%2.=``!,BR44G```08L\)/\5DIT`
M`,:`UPD```#IDO[__TB+/4>>``#_%6&<``!!B<3I6?___TB+/3J>``!(A?]T
M"V?H[RD``.EJ____2(T]*SX``$B)[NA[%P``2(D%%)X``$B)QTB%P`^$2/__
M_^O1O@0```#IX?[__[\!````_Q7AFP``_Q7SG```9BX/'X0``````)#S#Q[Z
M,>U)B=%>2(GB2(/D\%!413'`,<E(C3V1_?___Q5+G0``]&8N#Q^$``````!(
MC3UYG0``2(T%<IT``$@Y^'052(L%YIL``$B%P'0)_^`/'X``````PP\?@```
M``!(C3U)G0``2(TU0IT``$@I_DB)\$C![C](P?@#2`'&2-'^=!1(BP7%FP``
M2(7`=`C_X&8/'T0``,,/'X``````\P\>^H`]!9T```!U,U5(@SVZFP```$B)
MY70-2(L]UIP``/\5J)L``.AC____Q@7<G````5W#9BX/'X0``````,-F9BX/
M'X0```````\?0`#S#Q[ZZ6?___\/'X``````05=(B?Y,C4\X059!54%455-(
M@>R8`@``9$B+!"4H````2(F$)(@"```QP$B)XDR-E"2`````28G0#Q^`````
M`$&+`4F+.4F#P!!)@\$(#\B)P$B)^4F)0/!(B?A(P>D@2,'H*$C![S@E`/\`
M`$@)^$B)STC!X0A(P><8@>$``/\`B?]("?A("<A)B4#X33G0=:Y(C;H``@``
M#Q^``````$B+0FA(,T)`2(/""$@S0@A(,T+X2(T,`$C!Z!]("<B#X/](B4)X
M2#GZ==5,BPY,BUX02(M^($B+7AA,B<A,B<I(BVX(2(M,)`A(P>H;2,'@!4@)
MT`,$)$B-C`N9>8):C90XF7F"6DR)V$@QV$@AZ$@QV(T\`DB)ZDB)Z$C!Z`)(
MP>(>28GZ2`G"3(G82<'J&T&)T$PQP$PAR$PQV$@!R$B)^4C!X05,"=%,BU0D
M$$2-)`A,B<A,B<E(P>D"2,'@'D^-E!.9>8):38GE2`G(2<'M&T@QPHG!2"'Z
M3#'"3`'238GB2<'B!4T)ZDR+;"0800'22(GZ2,'O`DC!XAY%B=)/C80HF7F"
M6D@)^DV)U4@QT(G73"'@2<'M&T@QR$P!P$V)T$G!X`5-">A,BVPD($$!P$R)
MX$G![`)(P>`>18G`2HV,*9EY@EI,">!-B<5(,<))P>T;08G$3"'22#'Z2`'*
M3(G!2,'A!4P)Z4R+;"0H`=%,B=))P>H"2,'B'HG)2HV\+YEY@EI,"=))B<U(
M,=!)P>T;08G23"'`3#'@2`'X2(G/2,'G!4P)[TR+;"0P`<=,B<!)P>@"2,'@
M'HG_3XVD+)EY@EI,"<!)B?U(,<))P>T;08G`2"'*3#'23`'B28G\2<'D!4T)
M[$R+;"0X00'42(G*2,'I`DC!XAY%B>1/C90JF7F"6D@)RDV)Y4@QT$G![1N)
MT4@A^$PQP$P!T$V)XDG!X@5-">I,BVPD0$$!PDB)^$C![P)(P>`>18G23XV$
M*)EY@EI("?A-B=5(,<))P>T;B<=,(>)(,<I,`<)-B=!)P>`%30GH3(ML)$A!
M`=!,B>))P>P"2,'B'D6)P$J-C"F9>8):3`GB38G%2#'02<'M&T&)U$PAT$@Q
M^$@!R$R)P4C!X05,">E,BVPD4`'!3(G02<'J`DC!X!Z)R4J-O"^9>8):3`G0
M28G-2#'"2<'M&T&)PDPAPDPQXD@!^DB)STC!YP5,">],BVPD6`'73(G"2<'H
M`DC!XAZ)_T^-I"R9>8):3`G"28G]2#'02<'M&T&)T$@AR$PQT$P!X$F)_$G!
MY`5-">Q,BVPD8$$!Q$B)R$C!X!Y(P>D"18GD3XV4*IEY@EI("<A-B>5(,<))
MP>T;B<%((?I,,<),`=)-B>))P>(%30GJ3(ML)&A!`=)(B?I(P>\"2,'B'D6)
MTD^-A"B9>8):2`GZ38G52#'02<'M&XG73"'@2#'(3`'`38G02<'@!4T)Z$R+
M;"1P00'`3(G@2<'L`DC!X!Y%B<!*C8PIF7F"6DP)X$V)Q4@QPDG![1M!B<1,
M(=)(,?I(`<I,B<%(P>$%3`GI3(ML)'@!T4R)TDC!XAY)P>H"B<E*C;POF7F"
M6DP)TDF)S4@QT$G![1M!B=),(<!,,>!(`?A(B<](P><%3`GO3(NL)(`````!
MQTR)P$G!Z`)(P>`>B?]/C:0LF7F"6DP)P$F)_4@QPDG![1M!B<!((<I,,=),
M`>))B?Q)P>0%30GL1HTL(DB)RDC!Z0),BZ0DB````$C!XAY("<I/C90BF7F"
M6DV)[$@QT$G![!N)T4@A^$PQP$P!T$V)ZDG!X@5-">),BZ0DD````$$!PDB)
M^$C!X!Y(P>\"18G23XV$()EY@EI("?A-B=1(,<))P>P;B<=,(>I(,<I,`<)-
MB=!)P>`%30G@18G`3`'"38GH2<'M`DG!X!Y!B=1-">A,BZPDF````$PQP$PA
MT$J-C"F9>8):38GE2#'X2<'M&T@!R$R)X4C!X05,">F)R4@!R$R)T4G!Z@)(
MP>$>08G%3`G138G"18G`23'*1#'23(N4)*````!*C;P7H>O9;DV)ZD@!UTR)
MZDG!ZAM(P>(%3`G2B=)(`==,B>)(P>(>2<'L`D&)^DP#A"2H````3`GB28G,
MB<E(`XPDL````$DQU$0QX$V-I`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!
MQ$R)Z$G![0)(P>`>18G@3`GH28G5B=)(`Y0DN````$DQQ40Q[TR-K#FAZ]EN
M3(G!3(G'2,'O&TC!X05("?F)R4D!S4R)T4G!Z@)(P>$>1(GO3`G128G"B<!)
M,<I%,>).C:02H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=1,B<))P>@"2,'B
M'D6)XDP)PDF)R$@#A"3`````B<E),=!(`XPDR````$4QZ$Z-K`"AZ]EN3(G0
M38G02<'H&TC!X`5,"<")P$D!Q4B)^$C![P)(P>`>18GH2`GX2(G7B=)(`Y0D
MT````$@QQT0QYTR-I#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)R4D!S$R)T4G!
MZ@)(P>$>1(GG3`G128G"B<!(`X0DV````$DQRD4QZDZ-K!*AZ]EN2(GZ28GZ
M2<'J&TC!X@5,"=*)TDD!U4R)PDG!Z`)(P>(>18GJ3`G"28G(B<E),=!(`XPD
MX````$4QX$Z-I`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q$B)^$C![P)(
MP>`>18G@2`GX2(G7B=)(`Y0DZ````$@QQT0Q[TR-K#FAZ]EN3(G!3(G'2,'O
M&TC!X05("?F)R4D!S4R)T4G!Z@)(P>$>1(GO3`G128G"B<!(`X0D\````$DQ
MRD4QXDZ-I!*AZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(P>(>
M18GB3`G"28G(B<E),=!%,>A.C:P`H>O9;DR)T$V)T$C!X`5)P>@;2`.,)/@`
M``!,"<")P$D!Q4B)^$C![P)(P>`>18GH2`GX2(G7B=)(`Y0D``$``$@QQT0Q
MYTR-I#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)R4D!S$R)T4G!Z@)(P>$>1(GG
M3`G128G"B<!(`X0D"`$``$DQRD4QZDZ-K!*AZ]EN2(GZ28GZ2<'J&TC!X@5,
M"=*)TDD!U4R)PDG!Z`)(P>(>18GJ3`G"28G(B<E),=!%,>!.C:0`H>O9;DR)
MT$V)T$G!Z!M(P>`%3`G`2`.,)!`!``")P$D!Q$B)^$C![P)(P>`>18G@2`GX
M2(G7B=)(`Y0D&`$``$@QQT0Q[TR-K#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)
MR4D!S4R)T4G!Z@)(P>$>1(GO3`G128G"B<!(`X0D(`$``$DQRD4QXDZ-I!*A
MZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(P>(>18GB3`G"28G(
MB<E),=!%,>A.C:P`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)`<5(B?A(P>`>
M2,'O`D6)Z$@#C"0H`0``2`GX2(G7B=)(`Y0D,`$``$@QQT0QYTV)Q$B-C#FA
MZ]EN3(G'2<'L&TC!YP5,">=-B=1)P>H"2<'D'HG_30G428G"2`'YB<!-,>*)
MST@#A"0X`0``13'J28G]3HV4$J'KV6Y(B?I)P>T;2,'B!4P)ZD$!TDR)PDG!
MZ`)(P>(>18G23`G"38G@18GD23'028G608G51#'!38G02(V,"*'KV6Y,B=!)
MP>@;2,'@!4P)P$2-!`%(B?E(P>\"N-R\&X](P>$>2`GY20G.B<]((?I-(=9)
M"=9(BY0D0`$``$@!PDP!XDV)Q$P!\DV)QDG!Y`5)P>X;30GT00'43(G22<'J
M`DC!XAY%B>1,"=)("=%)B=9!B=))(?Y,(<%,"?%,B[0D2`$``$D!QDT!]4V)
MYDP!Z4V)Y4G![AM)P>4%30GU28G600'-3(G!2<'H`DC!X1Y%B>U,"<%!B<A)
M"<Y-(>9,(<),"?),B[0D4`$``$D!QDP!]TV)[D@!^DR)[TG![AM(P><%3`GW
M`==,B>))P>P"2,'B'HG_3`GB2`G128G608G432'&3"'I3`GQ3(NT)%@!``!)
M`<9-`?))B?Y,`=%)B?I)P>X;2<'B!4T)\DF)UD$!RDR)Z4G![0)(P>$>18G2
M3`GI08G-20G.22'^3"'J3`GR3(NT)&`!``!)`<9-`?!-B=9,`<)-B=!)P>`%
M2<'N&TT)\$$!T$B)^DC![P)(P>(>18G`2`GZ2`G128G6B==-(>Y,(=%,"?%,
MB[0D:`$``$D!QDT!]$V)QDP!X4V)Q$G![AM)P>0%30GT28G600',3(G12<'J
M`DC!X1Y%B>1,"=%!B<I)"<Y-(<9,(=),"?),B[0D<`$``$D!QDT!]4V)YDP!
MZDV)Y4G![AM)P>4%30GU00'53(G"2,'B'DG!Z`)%B>U,"<)("=%)B=9!B=!-
M(=9,(>%,"?%,B[0D>`$``$D!QDP!]TV)[D@!^4R)[TG![AM(P><%3`GW28G6
M`<],B>%)P>P"2,'A'HG_3`GA08G,20G.32'N3"'B3`GR3(NT)(`!``!)`<9-
M`?))B?Y,`=))B?I)P>X;2<'B!4T)\D$!TDR)ZDG![0)(P>(>18G23`GJ2`G1
M28G608G52"'Y32'F3`GQ3(NT)(@!``!)`<9-`?!-B=9,`<%-B=!)P>X;2<'@
M!4T)\$F)UD$!R$B)^4C![P)(P>$>18G`2`GYB<])"<Y-(=9((?I,"?),B[0D
MD`$``$D!QDT!]$V)QDP!XDV)Q$G![AM)P>0%30GT00'43(G22<'J`DC!XAY%
MB>1,"=)("=%)B=9!B=))(?Y,(<%,"?%,B[0DF`$``$D!QDT!]4V)YDP!Z4V)
MY4G![AM)P>4%30GU28G600'-3(G!2<'H`DC!X1Y%B>U,"<%!B<A)"<Y-(>9,
M(<),"?),B[0DH`$``$D!QDP!]TV)[D@!^DR)[TG![AM(P><%3`GW`==,B>))
MP>P"2,'B'HG_3`GB2`G128G608G432'&3"'I3`GQ3(NT)*@!``!)`<9-`?))
MB?Y,`=%)B?I)P>X;2<'B!4T)\DF)UD$!RDR)Z4G![0)(P>$>18G23`GI08G-
M20G.22'^3"'J3`GR3(NT)+`!``!)`<9-`?!-B=9,`<)-B=!)P>X;2<'@!4T)
M\$$!T$B)^DC![P)(P>(>18G`2`GZ2`G128G6B==-(>Y,(=%,"?%,B[0DN`$`
M`$D!QDT!]$V)QDP!X4V)Q$G![AM)P>0%30GT28G600',3(G12<'J`DC!X1Y%
MB>1,"=%)"<Y!B<I-(<9,(=),"?),B[0DP`$``$D!QDT!]4V)YDP!ZDV)Y4G!
M[AM)P>4%30GU00'53(G"2<'H`DC!XAY%B>U,"<)("=%)B=!!B==-(=!,(>%,
M"<%,BX0DR`$``$D!P$P!QTV)Z$@!^4R)[TG!Z!M(P><%3`G'1(T$.4R)YTG!
M[`)(B=%(P><>3`GG08G\2`GY3"'I3"'B2`G*2(N,)-`!``!(`<%,`=%-B<)(
M`X0DV`$``$@!RDR)P4G!ZAM(P>$%3`G1B<E(`<I,B>E)P>T"2,'A'D&)TDP)
MZ4@)STF)S4&)SDPAQTTAY4D)_4J-/#A,B=!,B[PD^`$``$P![TV)U4C!X`5)
MP>T;3`GHB<!(`<=,B<!)P>@"2,'@'D&)_4D)P+C6P6+*3#'!,=%(BY0DX`$`
M`$@!PDP!XDV)[$@!RDR)Z4G![!M(P>$%3`GA38G4B<E)P>0>2`'*2<'J`DD!
MQTT)XDV)Q(G118G`33'41#'G3(ND).@!``!)`<1-`?1)B<Y,`>=)B<Q)P>X;
M2<'D!4T)]$V)[DG![0))P>8>18GD30GU3(NT)/`!``!,`>=!B?Q)`<9-`?!-
MB=9-,>Y$,?)-B>9)`=!,B>))P>X;2,'B!4P)\HG220'02(G*2,'I`DC!XAY%
MB<9("<I$B=%-B>I),=),`?E,B[PD``(``$0QUTV)\D@!STR)\4C!X05)P>H;
M20''3`G1B<E(`<],B>%)P>P"2,'A'D&)^DD)S$2)Z4F)U8G233'E3`'Y3(N\
M)!`"``!%,>A-B=5)`<A,B=%)P>T;20''2,'A!4P)Z8G)20'(3(GQ2<'N`DC!
MX1Y%B<5,"?%,B[0D"`(``$D!QDP!\DV)YDDQSD0Q]TV)[D@!UTR)ZDG![AM(
MP>(%3`GRB=)(`==,B=))P>H"2,'B'D&)_DD)TD2)XDF)S(G)3`'Z33'43(N\
M)"`"``!%,>!-B?1)`=!,B?))P>P;20''2,'B!4P)XHG220'03(GJ2<'M`DC!
MXAY%B<1,">I,BZPD&`(``$D!Q4P!Z4V)U4DQU40Q[TV)Y4@!STR)X4G![1M(
MP>$%3`GIB<E(`<],B?%)P>X"2,'A'D&)_4D)SD2)T4F)THG233'R3`'Y3(N\
M)#`"``!%,=!-B>I)`<A,B>E)P>H;2,'A!4P)T8G)20'(3(GA2,'A'DG![`)%
MB<))`<=,">%,BZ0D*`(``$D!Q$P!XDV)]$DQS$0QYTV)U$@!UTR)TDG![!M(
MP>(%3`GBB=)(`==,B>I)P>T"2,'B'D&)_$D)U42)\DF)SHG)33'N3`'Z3(N\
M)$`"``!%,?!-B>9)`=!,B>))P>X;2,'B!4P)\HG220'03(G22<'J`DC!XAY%
MB<9,"=),BY0D.`(``$D!PDP!T4V)ZDDQTD0QUTV)\D@!STR)\4C!X05)P>H;
M20''3`G1B<E(`<],B>%)P>P"2,'A'D&)^DD)S$2)Z4F)U8G233'E3`'Y3(N\
M)&`"``!%,>A-B=5)`<A,B=%)P>T;2,'A!4P)Z8G)20'(3(GQ2<'N`DC!X1Y%
MB<5,"?%,B[0D2`(``$D!QDP!\DV)YD6)Y$DQSD0Q]TV)[D@!UTR)ZDG![AM(
MP>(%3`GRB=)(`==,B=))P>H"2,'B'D&)_DD)TDB+E"10`@``2`'"20'42(G*
MB<E,,=))`<=$,<)-B?!)`=1,B?))P>@;2,'B!4P)PHG220'43(GJ2<'M`DC!
MXAY%B>!,">I,BZPD6`(``$D!Q4P!Z4V)U4DQU40Q[TV)Q4@!STR)P4G![1M(
MP>$%3`GIB<E(`<],B?%)P>X"2,'A'D&)_4D)SD2)T4F)THG233'R3`'Y3(N\
M)'`"``!%,>)-B>Q,`=%-B>I)P>P;2<'B!4T)XDV)Q$6)TDG!Y!Y,`=%)P>@"
M20''30G@3(ND)&@"``!!B<I)`<1(`X0D>`(``$P!XDV)]$P!R$TQQ$0QYTV)
MU$@!UTR)TDG![!M(P>(%3`GB38GL2<'M`DG!Y!Z)TDT)Y46)]$V)QD@!UTTQ
M[HGZ30'\18G`1#'Q28G63`'`38GH3`'A28G42<'N&TG!Y`5-"?1$`>%-B=1)
MP>H"2<'D'HG)30GB33'01#''28G(2`'X2(G/2,'G!4G!Z!L!Z4$!VDP)QT0#
M;B!(B4X(`?A,B5882(D&2(G02,'J`DC!X!Y,B6X@2`G01`'82(E&$$B+A"2(
M`@``9$@K!"4H````=1)(@<28`@``6UU!7$%=05Y!7\/_%;>%``!F9BX/'X0`
M``````\?0`!!5T%6055!5%532(/L"$B%_P^$L0```$B+!4*$``!,BRA-A>T/
MA)X````/M@=)B?](B?6$P'0$/#UU544Q]DV+90!-A>1T,$UC]DR)ZP\?`$R)
M\DR)_DR)Y_\5280``(7`=0=#@#PT/71&3(MC"$B#PPA-A>1UV4B#Q`A,B>!;
M74%<05U!7D%?PP\?@`````!)B?Y!#[9&`4F#Q@&$P'0$/#UU[T4I_NN5#Q^`
M`````$PIZT^-9#0!2,'[`XE=`.NV#Q^``````$4QY.NJ#Q\`54B)_4B![*``
M``!D2(L$)2@```!(B80DF````#'`2(GF_Q7)A```A<!U-8M4)!B!X@#P``"!
M^@!```!T"('Z`*```'4=O@(```!(B>__%>V$``"%P`^4P`^VP.L%#Q\`,<!(
MBY0DF````&1(*Q0E*````'4)2('$H````%W#_Q54A```9F8N#Q^$``````"0
M059!54%455-(@>R@````9$B+!"4H````2(F$))@````QP$B%_W0(@#\`2(G]
M=3%(BX0DF````&1(*P0E*`````^%,0$``$B!Q*````!;74%<05U!7L-F+@\?
MA```````_Q5:@P``3(TMAR0``$F)Q$B%P'2Z3(GG_Q5BA```2(7`#X2Q````
M@'@3+DB-6!-U#X![`0!TWF8/'X0``````(!X$RX/A*8```!(B>__%?6"``!(
MB=])B<;_%>F"``!!C7P&`DAC__\5@X(``$F)V4F)Z$R)Z4F)QDB)Q[X!````
M,<!(Q\+______Q6H@P``3(GW2(GF_Q6\@@``3(GW@_C_=!"+1"08)0#P```]
M`$```'1<_Q5.@@``3(GW_Q5]@@``3(GG_Q6T@P``2(7`#X52____#Q\`3(GG
M_Q5/@P``2(GO_Q4F@@``Z>#^__^0@'L!+@^%4/___X![`@`/A!'____I0?__
M_P\?@`````#HB_[__^NC_Q7+@@``#Q\`\P\>^E-(BQU<@0``BSO_%=R"``"+
M._\5U((``$B+%36"``!(C0U^8@``2(TU22,``$B)Q_\5!H,``(L[_Q6N@@``
M3(T%V"0``$4QR5M(C16L'```2(G'3(G!2(TU-2,``/\E`8(``&8/'X0`````
M`$%6055!5%5(@>P`$```2(,,)`!(@^P8NO\/``!D2(L$)2@```!(B80D"!``
M`#'`28GE2(G]28GT2(T]_"(``$R)[O\5V($``(7`?E2-4/],8_)"@#PT``^%
M@P```(72=#],B?*^+P```$R)[_\5KH```$B%P'0I2(L%>H```(LX_Q7Z@0``
M3(GQ3(GJ2(GN2(G'_Q6`@0``ZR1F#Q]$``!(BP51@```BSC_%=&!``!,B>)(
MB>Y(B<?_%<J```!(BX0D"!```&1(*P0E*````'472('$&!```%U!7$%=05[#
M3&/PZ7G_____%6J!``!FD$%7059!54%454B)]5-(B?M(@^PH9$B+!"4H````
M2(E$)!@QP#'`@#X]#Y3`2`'%2(GO_Q60@```2(UT)!1(B=])B<0QP.AV^___
M2(7`#X0-`0``28G%2(G'_Q5I@```23G$#X;8````2&-,)!1,BS6L?P``3(T\
MS0`````/M@.$P`^$H0$``#P]#X29`0``2(G89@\?1```#[90`4B#P`&$TG0%
M@/H]=>](*=A(F$V++DJ-?"`"_Q6T?P``30']28E%`$B%P'1128L&2(U+`4J+
M%#@/M@.(`H3`="$\/74,ZQMF#Q]$``"$P'01#[8!2(/"`4B#P0&(`CP]=>O&
M`CTQP&8/'T0```^V3`4`B$P"`4B#P`&$R77O2(M$)!AD2"L$)2@````/A0\!
M``!(@\0H6UU!7$%=05Y!7\,/'T``,<!F#Q]$```/ME0%`$&(5`4`2(/``832
M=>[KO0\?0`!,BS6Y?@``38L&28,X``^$NP```$R)P$4Q[68/'T0``$B#P`A$
MB>I!@\4!2(,X`'7OC7(#2&/V2,'F`XL%KX```(7`=5M(B?=,B40D",<%F8``
M``$```#_%;-^``!(B<=(A<`/A%#___])8\U(BW0D"$R-/,T`````3(GZ_Q56
M?P``28D&2(G'08U%`42);"042)A(QP3'`````.E\_O__3(G'_Q7/?P``28D&
M2(G'2(7`#X0!____26/-3(T\S0````#KPP\?`#'`Z7_^__^^$````$4Q[>E?
M_____Q4F?P``9F8N#Q^$```````/'P#S#Q[Z2(/L"$B+!:E]``"+./\5*7\`
M`$B+%8I^``!(@\0(2(T-SUX``$B)QTB--9<?``#_)5=_```/'X``````\P\>
M^D%455-(@>P`$```2(,,)`!(@>P`$```2(,,)`!(@^P@9$B+!"4H````2(F$
M)!@@```QP$B-K"00$```28GD_Q7(?0``3(T-=Q\``+H!$```2(GO08G`2(T-
M:1\``+X!````,<#_%;I^``"Z`!```$R)YDB)[_\5(7X``$4QP(7`>#"->`%(
MB<-(8___%4M]``!)B<!(A<!T&4ACVTR)YDB)QTB)VO\5N7X``,8$&`!)B<!(
MBX0D&"```&1(*P0E*````'4/2('$("```$R)P%M=05S#_Q7Z?0``9I#S#Q[Z
MZ1?___^09@\?1```\P\>^D%7059!54%455-(@>P`$```2(,,)`!(@>S(````
M9$B+!"4H````2(F$)+@0```QP$B)_4F)]$B-/:<>``!(C70D'.CU]___OB\`
M``!(B>](B</_%61]``!(A<!T/S'`2(GN2(T]A!X``.@._/__2(GH2(N4)+@0
M``!D2"L4)2@````/A8,!``!(@<3($```6UU!7$%=05Y!7\-FD$B)[_\5GWP`
M`$R)YTR-)4L>``!!B<;_%1Q]``!,B>9(B<?_%3!]``!)B<5(A<!TD4&-1@%!
M@'T``$R--2$?``")1"0,#X3&````9@\?1```2(7;=!1,B>Y(B=__%>]\``"%
MP`^$A0```$R)[_\5-GP``.L'#Q]``,8"`(G!@^@!2&/03`'J@#HO=.T#3"0,
M@?G_#P``#X\F____3(V\)+````!,B?%-B>@QP$B#[`BZ`!```+X!````3(G_
M54R-#9P=``#_%<Y\``!,B?](C70D,/\5X'L``%I9A<!U$(M$)#@E`/```#T`
M@```=%),B>8Q__\57WP``$F)Q4B%P`^$O/[__T&`?0``#X5`____2(7;=`6`
M.RYT%DR-+24=``"Y`0```.E@____#Q]$``"`>P$`=+CKX@\?A```````O@$`
M``!,B?__%6)\``"%P'6<3(G^2(T]]1P``.A_^O__3(G__Q7.>P``Z6;^____
M%=-[``!F9BX/'X0``````/,/'OH/M@=)B?B$P'039I!(@\<!/"\/M@=,#T3'
MA,!U[TR)P,-F9BX/'X0``````/,/'OI(A?\/A,,```!5@#\`2(G]#X2>````
M_Q78>@``2(U4!?](.=5R#^F7````D$B#Z@%(.=5T)8`Z+W3R2#G5#X-_````
M2(/J`4@YU70.@#HO="A(@^H!2#G5=?*`?0`O=%1(C3U%'```7?\E%GL``&8/
M'T0``(`Z+W4)2(/J`4@YU7+R2"GJ,<!(C4H"2('Y`!```'<92(/"`;D`$```
M2(GN2(T]]7L``/\5CWD``%W##Q]$``!(C3W7&P``7?\EPGH``$@YU76RZY$/
M'P!(C3V_&P``_R6K>@``#Q\`\P\>^D%7059!54%455-(C1V]&P``2(/L2&8/
M;P6/6@``9$B+!"4H````2(E$)#@QP#'`2(UL)`P/*40D$&8/;P5[6@``9HE$
M)#`/*40D()`QP$B)[DB)W^BS]/__2(7`=#Y(BP4'>0``2&-4)`Q(BP!(C030
M2(M0"$B)$$B%TG3/#Q^``````$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$B-
M'30;``!F#Q^$```````QP$B)[DB)W^A3]/__2(7`=#Y(BP6G>```2&-4)`Q(
MBP!(C0302(M0"$B)$$B%TG3/#Q^``````$B+4!!(@\`(2(D02(72=?#KMF8/
M'T0``$B-'=P:``!F#Q^$```````QP$B)[DB)W^CS\___2(7`=#Y(BP5'>```
M2&-4)`Q(BP!(C0302(M0"$B)$$B%TG3/#Q^``````$B+4!!(@\`(2(D02(72
M=?#KMF8/'T0``$B-'84:``!F#Q^$```````QP$B)[DB)W^B3\___2(7`=#Y(
MBP7G=P``2&-4)`Q(BP!(C0302(M0"$B)$$B%TG3/#Q^``````$B+4!!(@\`(
M2(D02(72=?#KMF8/'T0``$R-)2P:``!F#Q^$```````QP$B)[DR)Y^@S\___
M2(7`=#Y(BP6'=P``2&-4)`Q(BP!(C0302(M0"$B)$$B%TG3/#Q^``````$B+
M4!!(@\`(2(D02(72=?#KMF8/'T0``$B-'=P9``!F#Q^$```````QP$B)[DB)
MW^C3\O__2(7`=#Y(BP4G=P``2&-4)`Q(BP!(C0302(M0"$B)$$B%TG3/#Q^`
M`````$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$R-+3$9``!F#Q^$```````Q
MP$B)[DR)[^AS\O__2(7`=#Y(BP7'=@``2&-4)`Q(BP!(C0302(M0"$B)$$B%
MTG3/#Q^``````$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$R-/2@9``!F#Q^$
M```````QP$B)[DR)_^@3\O__2(7`=#Y(BP5G=@``2&-4)`Q(BP!(C0302(M0
M"$B)$$B%TG3/#Q^``````$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$R--=(8
M``!F#Q^$```````QP$B)[DR)]^BS\?__2(7`=#Y(BP4'=@``2&-4)`Q(BP!(
MC0302(M0"$B)$$B%TG3/#Q^``````$B+4!!(@\`(2(D02(72=?#KMF8/'T0`
M`$B-'7P8``!F#Q^$```````QP$B)[DB)W^A3\?__2(7`=#Y(BP6G=0``2&-4
M)`Q(BP!(C0302(M0"$B)$$B%TG3/#Q^``````$B+4!!(@\`(2(D02(72=?#K
MMF8/'T0``$B-';H7``!F#Q^$```````QP$B)[DB)W^CS\/__2(7`=#Y(BP5'
M=0``2&-4)`Q(BP!(C0302(M0"$B)$$B%TG3/#Q^``````$B+4!!(@\`(2(D0
M2(72=?#KMF8/'T0``$B)[DB-/<,7``#HH?#__TB)QDB%P'0*3(GW,<#HS_3_
M_TB)[DB-/;,7```QP.A^\/__2(G&2(7`=`Y(C3VO%P``,<#HJ/3__TB)[DB-
M/:D7```QP.A7\/__2(G&2(7`=#I,B>\QP.B%]/__,<!(C36S%P``3(GGZ'3T
M__](BT0D.&1(*P0E*````'552(/$2%M=05Q!74%>05_#2(GN2(T]9A<``#'`
MZ`3P__](B<9(A<!T#$R)_S'`Z#+T___KJTBX4$%27T-,14%(.40D(76:9H%\
M)"E./7612(UT)"OKT_\5<74``&8/'X0``````/,/'OI(@^P89$B+!"4H````
M2(E$)`B+!01V``"#^/]T'TB+5"0(9$@K%"4H````=49(@\08PV8N#Q^$````
M``!(C70D!$B-/7,6```QP.AM[___2(G",<!(A=)T$@^V`CPP#Y7"A,`/E<`/
MML`AT(D%JW4``.NJ_Q7K=```#Q\`\P\>^DB#[`C_%?IT``")Q_\5$G0``$B%
MP'0#2(L`2(/$",-F9BX/'X0``````&:0\P\>^D%5051,C25Z%@``54B)_4R)
MYU-(@^P89$B+!"4H````2(E$)`@QP$B-="0$Z-ON__](A<!T"(`X`$B)PW4N
M2(M$)`AD2"L$)2@````/A;0```!(B>Y(@\083(GG,<!;74%<05WIX_+__P\?
M`$B)[DB)Q_\5]',``$B%P'0?2(M$)`AD2"L$)2@```!U>4B#Q!A;74%<05W#
M#Q]``$B)[_\5;W,``$B)WTF)Q?\58W,``$F-?`4"_Q4`<P``2(/L"$F)Z+X!
M````4TC'PO____](B<=)B<5,C0WM%```2(T-Z14``#'`_Q48=```6%I(BT0D
M"&1(*P0E*````'4(3(GNZ4______%:AS``#S#Q[Z2(/L"+^`````_Q6=<@``
MNHFKS>^Y_MRZF+[PX=+#2,<``2-%9TB)4`A(B4@02,=`&'94,A!(B7`@2,=`
M*`````!(QT`P`````,=`>`````!(@\0(PP\?@`````#S#Q[Z051)B?Q54TB#
M[!!D2(L$)2@```!(B40D"#'`9^B+]___#[802(G%A-)T$Y!(@\`!@/HO#[80
M2`]$Z(32=>Z+!;AS``!-A>0/E<.#^/]T;87`#Y7`(<.$VW4B2(M$)`AD2"L$
M)2@````/A8\```!(@\006UU!7,,/'T0``$&`/"0`=->Z!````$B--984``!(
MB>__%:QQ``"%P'6^2(M$)`AD2"L$)2@```!U44B#Q!!,B>=;74%<Z4#N__\Q
MP$B-="0$2(T]T1,``.C-[/__2(7`=`L/M@"$P'0$/#!U#\<%$W,```````#I
M;/___\<%!',```$```#I6?____\507(``&8/'X0``````/,/'OI!5TACPD%6
M28G&055!5$F)_%5(C6\X4TB)\TB#[`A(BW<H2(M7,(T,QD@Y\4B)3RA(@](`
M2,'H'4@!T$B)1S!(8T=XA<`/A>D```!!@_X_#XXO`0``08/N0$6)]T'![P9%
MC6\!2<'E!DD!W9#S#V\#3(GG2(/#0`\110#S#V]+T`\131#S#V]3X`\152#S
M#V];\`\173#HL=7__TPYZW7,0<'G!D4I_DECQDB#^`AR7$F+50!(C4T(2(/A
M^$F)5"0X28M4!?A(B50%^$@IS4@!Z$DI[4B#X/A(@_@(<AA(@^#X,=))BW05
M`$B)-!%(@\((2#G"<NY%B70D>$B#Q`A;74%<05U!7D%?PV:0J`1U?$B%P'3A
M00^V50!!B%0D.*@"=--!#[=4!?YFB50%_NO&#Q]``$&]0````$B-?`4`2(G>
M02G%13GU10]/[DUC_4R)^O\5;'$``$&+1"1X1`'H08E$)'B#^$!UD4R)YT4I
M[DP!^^C4U/__Z<[^__\/'X``````28G=Z1O___]!BU4`08E4)#A!BU0%_(E4
M!?SI4____V8/'X0``````/,/'OI!5DR-=CA!54%454B)]5-(BT8H2(G[1(MF
M*$2+;C!(P>@#@^`_00_,00_-C4@!2)C&1`8X@$ACP4P!\(/Y.`^.&`$``+Y`
M````*<YT#S'2B=&#P@'&!`@`.?)R\TB)[^@XU/__9@_OP`\113A)QT8P````
M`$$/$48000\11B!$B6UP2(GO1(EE=.@.U/__2(M%`$B)[TC!Z!B(`TB+10!(
MP>@0B$,!2(M%`(AC`DB+10"(0P-(BT4(2,'H&(A#!$B+10A(P>@0B$,%2(M%
M"(AC!DB+10B(0P=(BT402,'H&(A#"$B+11!(P>@0B$,)2(M%$(AC"DB+11"(
M0PM(BT482,'H&(A##$B+11A(P>@0B$,-2(M%&(AC#DB+11B(0P](BT4@2,'H
M&(A#$$B+12!(P>@0B$,12(M%((AC$DB+12"(0Q-;74%<05U!7O\EBFX``&8N
M#Q^$``````"Z.````#'_*<J#^@AR0HG12,<``````$C'1`CX`````$B-2`A(
M@^'X2"G(`<*#XOB#^@@/@NG^__^#XO@QP(G&@\`(2(D\,3G0<O/ITO[___;"
M!'4CA=(/A,7^___&``#VP@(/A+G^__\QR6:)3!#^Z:W^__\/'P#'``````#'
M1!#\`````.F7_O__#Q]$``#S#Q[Z05=!5D%505154TR-G"0`@/__2('L`!``
M`$B##"0`3#G<=>](@>QH`0``3(TU8P\``$B)?"0(2(UL)"Q,B?=(B>YD2(L$
M)2@```!(B80D6($``$B-!3,0``!(QT0D8`````!(QX0DF`````````!(QT0D
M0`````!(B40D4$B-!0\/``!(B40D6$B-!98/``!(B40D>$B-!?8/``!(B80D
M@````$B-!9@/``!(B80DB````$B-!>`/``!(B80DD````$B-!;@/``!(B40D
M,$B-!<D/``!(B40D.#'`Z`SH__](A<!T#(`X`$F)Q`^%VP0``/\5O6T``(G'
M_Q75;```2(7`#X04!```3(LH387M#X0(!```3(GO_Q77;```2(U\``'_%71L
M``!%#[9%`$F)Q$6$P'0_38GG2(T=9P\```\?1```28/%`44/ML!,B?](B=E(
MQ\+_____O@$````QP$F#QP+_%7IM``!%#[9%`$6$P'702(U<)'!(C3VL#@``
MZQMF+@\?A```````2(M["$B#PPA(A?\/A$\!``!(B>XQP.A%Y___28G%2(7`
M=-V`.`!TV$B)Q^@`Z/__A<!TS$R)[_\5NVP``$F)P$B%P`^$%P$```\?@```
M``!,B40D$$R)Q_\5"FP``$R)YTB)P_\5_FL``$2-O`,$!```36/_3(G__Q62
M:P``051,C0V9#0``2(T-D0X``$F)Q4B-!5$.``!(Q\+_____O@$```!03(GO
M3(M$)"`QP/\5HVP``$R)[[[``0``_Q7E;```7T%8@_C_=1/_%1]L``!$BPA!
M@_D1#X4H`P``2(V$)*````!,B>](B40D$$B)QO\5*6P``(G#A<`/A+\```!(
MBT0D"$V)Z+X!````13'D2(T5L`X``$B+"$B+!3YL``!(BS@QP/\5JVH``$B+
MA"18@0``9$@K!"4H````#X7U!0``2('$:($``$R)X%M=05Q!74%>05_##Q^`
M`````$R-+9D-```QV^L9#Q]$``!(8\-,BVS$4$V%[70[08!]``!T-$R)[X/#
M`>BAYO__A<!TW4R)[_\57&L``$F)P$B%P`^%J/[__TACPTR+;,10387M=<@/
M'P!%,<#ID/[__XN$)+@````E`/```#T`0```#X4J____1(ND)+P```#_%4-K
M``!!.<0/A1/___](BT0D"$B+`$B)1"08BX0DN````"7_`0``/<`!```/A>_^
M__],B?__%?5I``!(B>Y(C3V_#```28G$,<#H,>7__TB)QDB%P`^$10(``$B+
M?"089^C:[/__28G'2(7`#X0N`@``3(G__Q4-:@``2(G"@_@#?CU(F$B)5"08
M2(TUMPP``$F-?`?\_Q64:@``A<!U($B+5"08@_H$#X3P`P``C4+[2)A!@#P'
M+P^$X`,``&:0BP4::P``@_C_#X2)`P``2(T]J0L``(7`#X39`0``2(TU$@P`
M`#'`2(TMDPP``.C-Z/__3(T]=0P``/\58&D``%5(Q\+_____38GH4$R-#2T+
M``"^`0```$R)YTB-#3\,```QP/\53FH``%A:ZT5FD/\5VFD``(,X$75+_Q4?
M:0``@\,!2(/L"$V)Z%5,C0WM"@``3(GYO@$```!32,?"_____TR)YU`QP/\5
M"6H``$B#Q""^P`$``$R)Y_\51VH``(/X_W2J3(GO_Q7Q:```3(GW3(GF,<#H
M).C__TR)YV?HR_3__^FC_?__9@\?1```,=M(C3U;"P``ZQ(/'T0``$ACPTB+
M?,0P2(7_=#E(B>XQP(/#`>BFX___2(7`=.&`.`!TW$B)Q_\5*VD``$F)Q4B%
MP`^%K_O__TACPTB+?,0P2(7_=<>_#0```$R-+0<+``#_%1AH``!!N%,```!)
MB<3IH_O__TB+1"0(38GHO@$```!%,>1(C15K"P``2(L(2(L%.6D``$B+.#'`
M_Q6F9P``Z?;\__]F#Q^$``````!(B<=GZ`?T__](BX0D6($``&1(*P0E*```
M``^%V0(``$B!Q&B!``!,B>=;74%<05U!7D%?_R5^:```9@\?1```2(M$)`A,
MBSCIQ?W__\<%*6D```````!,B?\Q]C'`_Q44:```2(T]M`D``(G%A<`/A`G^
M__](C9PD4`$``+H"````2,?&[O___XG'_Q5W:```N@8```!(B=Z)[_\5'V<`
M`("\)%`!````=0Z`O"11`0``0P^$U@$``#'2,?:)[_\50V@``+^`````_Q4`
M9P``2,<``2-%9TF)Q[B)J\WO28E'"$@MB\X25TF)1Q!(!?($&"M)QT<8=E0R
M$$F)1R!)QT<H`````$G'1S``````0<='>`````#K$P\?@`````!(B=Y,B?]G
MZ&3U__^Z`(```$B)WHGO_Q6$9@``B<*%P'_>B>](C:PD,`$``$B-'8<)``#_
M%1]F``!,B?Y(B>]GZ-OV__](C80DR````$R+?"002(E$)`AF#Q^$``````!$
M#[9%`$R)_TB)V;X!````2,?"_____S'`2(/%`4F#QP+_%7%G``!,.7PD"'72
M2(T%;`D``,:$),@`````4/]T)!A(C0TI"0``38GH3(GG,<"^`0```$R-#0,(
M``!(Q\+______Q4N9P``65[I-?W__P\?@`````!(C3T@"```,<!(B>Y(B7PD
M".@2X?__2(7`#X0V_O__#[8`A,`/A"O^__\\,`^$(_[__\<%3&<```$```!(
MBWPD".E`_/__2(M$)`A(BU`(2(72#X00_/__2(E4)`A(B=?_%<IE``!(@_@#
M#X;X^___2(M4)`A(C35Y"```2(U\`OS_%5%F``!(BU0D"(7`3`]$^NG1^___
M@+PD4@$``$$/A1S^__^`O"13`0``0P^%#O[__X"\)%0!``!(#X4`_O__@+PD
M50$``$4/A?+]__^Z`@```$C'QL;___^)[_\5+68``+HI````2(G>B>__%=5D
M``!(C04O"```4%/IR?[___\5R64``)#S#Q[Z055!5%532(/L&$B+'5-D``!D
M2(L$)2@```!(B40D"#'`BSO_%<-E``"+.TB)Q?\5N&4```^VE;````!(C6PD
M!$B-/;@&``!(B>Z(D+$````QP.C%W___2(7`=`F`.#$/A*<!```QP&?HG^K_
M_XL[_Q5W90``N0,```"Z`0```$B--98'``!(B<?_%4UD``!)B<1(A<!T-DB+
M0!"+.TR+*/\51F4``$B-%7$'``!(B<=,B>[_%3MD``!)BT0D$$R+($'V1"0.
M0`^%=P$``(L[_Q4790``N0,```"Z`0```$B--3T'``!(B<?_%>UC``!)B<1(
MA<!T/$B-/<\%``!(B>XQP.@4W___BSM)B<5)BT0D$$V%[0^$`0$``$R+(/\5
MR&0``$R)ZDB)QTR)YO\5P6,``(L[_Q6Q9```N@$```!(C37>!@``2(G'_Q4,
M8P``BSM)B<3_%9%D``!,B>9(C175!@``2(G'_Q6&8P``BSO_%79D``!(B>Y(
MC3U$!0``QH"Q`````#'`Z([>__](B04G90``28G$2(7`=#^^P`$``$R)Y_\5
MN60``(U0`8/Z`78)@_@1#X6A````2(M$)`AD2"L$)2@````/A:L```!(@\08
M6UU!7$%=PY!(BSWA9```9^A#]?__2(D%S&0``$F)Q$B%P'6E2(T]W08``#'`
M_Q7M8P``#Q]$``"`>`$`#X17_O__Z4K^__^02(L5H60``$R+($R+*O\5O6,`
M`$R)YTR)[N@RX?__Z?3^__\/'T0``(L[_Q6@8P``3(GF2(G'_Q5D8P``Z7#^
M__^)P4B+!5YD``!,B>)(C3V4!@``2(LP,<#_%7EC``#_%4-C``!F+@\?A```
M````D/,/'OI(BPW=8P``_R478@``````\P\>^DB#[`A(@\0(PP``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!)
M;G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R]S96QF+V5X90`O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0
M051(`'!A<BT`+64`+2T`55-%4@!365-414T`+W1M<`!414U01$E2`%1-4`!5
M4T523D%-10`E,#)X`"5S)7,E<R5S`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E
M<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`&`!P97)L`#``4$%2
M.CI086-K97(Z.E9%4E-)3TX`,2XP-30``````"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````
M```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A
M<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R
M;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L
M("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE
M*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ
M4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P
M87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M
M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M
M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*
M:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T
M;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*
M1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&
M25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@
M)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL
M92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@
M7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]
M8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@
M)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE
M;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ
M<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N
M=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["B1005)?34%'24,@/2`B
M7&Y005(N<&U<;B(["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE
M9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV
M*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H
M"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I
M+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I
M;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>
M35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D[
M"F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R
M7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?
M5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI-04=)0SH@
M>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N
M(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A
M9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE
M<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D
M8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M
M<R!?1D@["FUY("1M86=I8U]P;W,@/2`D<VEZ92`M("1S:7IE("4@)&-H=6YK
M7W-I>F4[(",@3D]413H@)&UA9VEC7W!O<R!I<R!A(&UU;'1I<&QE(&]F("1C
M:'5N:U]S:7IE"G=H:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L
M("1M86=I8U]P;W,L(#`["G)E860@7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K
M(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F
M+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T
M.PI]"B1M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*:68@*"1M86=I8U]P
M;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B10
M05)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*
M?0IS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F
M+"`T.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D
M8G5F*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI
M<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@
M("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&
M24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q
M6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H
M("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD
M968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I
M/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD
M("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M
M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE
M;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@
M)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL
M96YA;65<;B(I.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]
M('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M
M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L
M("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M
M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L
M93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U
M;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD
M24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D
M14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2![
M"FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T
M(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^
M<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@
M)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M
M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F
M:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D
M:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H
M.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D
M=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D
M9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*
M?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I
M=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD
M9FEL96YA;65].PI]"G5N;&5S<R`H)&)U9B!E<2`B4$M<,#`S7#`P-"(I('L*
M;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]
M("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II
M<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U
M:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P
M;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI
M('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS
M=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V
M97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U
M<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI
M9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY
M($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM
M*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=)
M)RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG
M*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H
M:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T
M(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G
M.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L
M<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@
M)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@
M;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@
M>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C
M;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=]
M.PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?
M=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM
M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#
M86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)
M3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI
M=F4@(B1P87(B73L*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@
M)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]
M?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A
M(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#
M86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D
M("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL
M95T@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*
M0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O
M=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH
M*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A
M;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*
M<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1D871A
M7W!O<RD@>PIR96%D(%]&2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@
M>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D
M14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E
M;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C
M:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD
M:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;
M)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B
M7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD
M;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G
M('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP
M<FEN="@D;&]A9&5R*3L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC
M*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$
M4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D
M0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\
M?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`
M1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM
M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@
M("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A
M8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N
M86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*
M?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^
M(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME
M>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO
M*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D
M9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*
M;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT
M(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ
M<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[
M;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI
M('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O
M(#T@=6YD968["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@
M<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1F:#X[
M"F-L;W-E("1F:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O
M;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE
M;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z
M.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.
M)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*3L*;W5T<RAQ<5M7<FET
M=&5N(&%S("(D;F%M92)=*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE
M*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA
M;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H
M,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE
M*"1F:"D["F-L;W-E("1F:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E
M<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C
M:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H
M)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*
M)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@
M=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR
M97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI[
M"G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD
M;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D
M;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z
M:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU
M;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`[
M"B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A
M)$5.5GM005)?1$5"54=].PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@
M>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI
M<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?
M;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL
M92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@
M86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U
M=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M
M92)=*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]
M"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID
M:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R
M(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R
M86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%2
M1U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X
M="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG
M*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P
M871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R
M;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I
M<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC
M=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A
M<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E
M($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E
M8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@
M24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S
M<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T
M.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T
M=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER
M92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A
M;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R
M97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U
M:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@
M<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D
M<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!4
M14U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2![
M"FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M
M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U
M:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I
M;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R
M.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R
M;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T52
M3D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@
M/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]
M<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER
M+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@
M*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L
M("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@
M)"%=.PIS965K("1F:"P@+3$X+"`R.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U
M9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L
M(#(["G)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M
M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]8V%C:&4M)&)U9B(["GT*96QS92!["FUY
M("1D:6=E<W0@/2!E=F%L"GL*<F5Q=6ER92!$:6=E<W0Z.E-(03L*;7D@)&-T
M>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR87<B
M+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z
M("0A73L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8W1X+3YH
M97AD:6=E<W0["GT@?'P@)&UT:6UE.PHD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L
M:6U]8V%C:&4M)&1I9V5S="(["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.
M5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?71E
M;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S
M=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B
M(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?
M.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M
M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"([
M"F]P96X@;7D@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64@;W(@9&EE('%Q6T-A
M;B=T('=R:71E("(D=&5M<&YA;64B.B`D(5T["G!R:6YT("1F:"`D8V]N=&5N
M=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I
M;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N
M;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S
M971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@
M86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE
M(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!]
M(&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2![
M"B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA
M;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.
M04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@
M>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I
M9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD
M<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(
M?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E
M<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D
M+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D
M<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R
M;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI
M;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P
M<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R
M;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S
M>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#
M=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS
M,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H
M)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]
M7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%2
M7TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.
M5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%
M35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%
M3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$
M14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?
M)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@
M)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%
M04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI
M('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H
M*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^
M("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF
M("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]
M"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U
M:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N
M9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I
M=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E
M>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)
M3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*
M9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N
M86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@
M)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D
M0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*
M)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D
M.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?
M15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH```!P97)L>'-I+F,`
M``````````````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M(`$;`SO<````&@```+"`__\(!0```(/___@`````A/__$`$``$":__]@`0``
M$)O__ZP!``"@F___T`$``""=__\4`@``D)W__S`"``"`GO__<`(``-"@__^\
M`@``$*'__]0"``#PH?__$`,```"B__\D`P``(*3__X@#``!0I/__G`,``#"E
M___,`P``@*K__QP$````J___.`0``#"K__]0!```0*S__ZP$``"@K/__Q`0`
M`+"M__\T!0``8*___X`%``!0L?__P`4``""Z__^<!@``L+S__]@&````````
M%``````````!>E(``7@0`1L,!PB0`0``%````!P`````@O__)@````!$!Q``
M````3````#0```#H@O__,18```!"#A"/`DD.&(X#0@X@C01"#BB,!4$.,(8&
M00XX@P='#M`%`P@6"@XX00XP00XH0@X@0@X80@X00@X(00L```!(````A```
M`-B8___-`````$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)M
M"@XX1`XP00XH0@X@0@X80@X00@X(2`L`(````-````!<F?__A`````!!#A"&
M`DH.L`$"<0H.$$$."$$+0````/0```#(F?__?0$```!"#A".`D(.&(T#0@X@
MC`1!#BB&!4$.,(,&1P[0`7X*#C!!#BA!#B!"#AA"#A!"#@A+"P`8````.`$`
M``2;__]G`````$4.$(,"`D@."```/````%0!``!8F___[@````!"#A".`D(.
M&(T#0@X@C`1!#BB&!4<.J"!)#L`@`L$*#BA!#B!"#AA"#A!"#@A!"T@```"4
M`0``")S__T("````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D0..(,'1PY@
M`QT!"@XX00XP00XH0@X@0@X80@X00@X(10L4````X`$```R>__\Y`````$@.
M$%H."``X````^`$``#2>___>`````$8.$(P"00X8A@-!#B"#!$<.H"!,#J!`
M20[`0`*L"@X@1`X800X00@X(00L0````-`(``-B>__\*`````````&````!(
M`@``U)[__Q4"````1@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1PZX
M($P.@"("<@H..$$.,$$.*$(.($(.&$(.$$(."$,+`J\.B").#I`B7`Z((D$.
M@"(````0````K`(``)"@__\E`````````"P```#``@``K*#__]T`````3@X0
MA@("7@K&#@A,"WH*#@A&"T@*Q@X(1@M*#@C&`$P```#P`@``7*'__T<%````
M1@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'2PZ``0/7!`H..$$.,$$.
M*$(.($(.&$(.$$(."$$+````&````$`#``!<IO__?0````!(#B!M"@X(2PL`
M`!0```!<`P``P*;__R,`````2`X06@X(`%@```!T`P``V*;__Q`!````1@X0
MC0)"#AB,`T@.((8$1PXH@P5$#D`"0@H.*$8.($$.&$(.$$(."$@+90H.*$$.
M($$.&$(.$$(."$4+9`Y(20Y09`Y(00Y`````%````-`#``",I___60````!(
M#A`"4`X(0````.@#``#4I___!P$```!&#A",`D0.&(8#00X@@P1$#C`"9PH.
M($$.&$$.$$(."$8+=`H.($0.&$$.$$(."$4+```H````+`0``*![__]%`@``
M`$8.$(P"00X8A@-$#E`#D`$*#AA$#A!"#@A!"T@```!8!```=*C__Z<!````
M1@X0CP)%#AB.`T4.((T$0@XHC`5$#C"&!D4..(,'1PY``N$*#CA!#C!!#BA"
M#B!"#AA"#A!"#@A#"P`\````I`0``-BI___K`0```$8.$(X"1@X8C0-"#B",
M!$$.*(8%1`XP@P8#-@$*#BA!#B!"#AA"#A!"#@A0"P``V````.0$``"(J___
MSP@```!&#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P=(#`NX@`)1#0='
M#J"#`@/B`0ZH@P)E#K"#`E\.J(,"0@Z@@P("A0H..$0.,$$.*$(.($(.&$(.
M$$(."$@+`X$!#JB#`DL.L(,"7PZH@P)!#J"#`EP.J(,"1`ZP@P)0#KB#`DL.
MP(,"3`Z@@P(#%`$*#CA$#C!!#BA"#B!"#AA"#A!"#@A,"P-^`0ZH@P)$#K"#
M`FD.J(,"00Z@@P(#!P$*#JB#`D$.L(,"10L``#@```#`!0``?+/__X4"````
M1@X0C0)"#AB,`T$.((8$00XH@P5$#D`#R@$*#BA!#B!!#AA"#A!"#@A""Q``
M``#\!0``T+7__Q$`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````8",````````0(P````````$`````````Y0(````````!````````
M`/`"````````#P````````!Q!`````````P``````````"`````````-````
M`````#1<````````&0````````#PNP```````!L`````````"``````````:
M`````````/B[````````'``````````(`````````/7^_V\`````T`,`````
M```%`````````.`-````````!@`````````0!0````````H`````````E`0`
M```````+`````````!@`````````%0````````````````````<`````````
ML!,````````(`````````*@&````````"0`````````8`````````!@`````
M``````````````#[__]O``````$```@`````_O__;P`````P$P```````/__
M_V\``````0````````#P__]O`````'02````````^?__;P`````$````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````+P`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````_____P````#@8@```````$=#
M0SH@*$=.52D@,3$N,BXP```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N
M<')O<&5R='D`+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N
M=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S
M:6]N7W(`+G)E;&$N9'EN`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H
M7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`
M+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT````````````````
M````````````````````````````````````````````````````````````
M```````````````+`````0````(`````````&`,````````8`P```````!P`
M```````````````````!````````````````````$P````<````"````````
M`#@#````````.`,```````!0````````````````````"```````````````
M`````"8````'`````@````````"(`P```````(@#````````)```````````
M``````````0````````````````````Y````!P````(`````````K`,`````
M``"L`P```````"`````````````````````$````````````````````1P``
M`/;__V\"`````````-`#````````T`,```````!``0````````8`````````
M"````````````````````%$````+`````@`````````0!0```````!`%````
M````T`@````````'`````0````@`````````&`````````!9`````P````(`
M````````X`T```````#@#0```````)0$```````````````````!````````
M````````````80```/___V\"`````````'02````````=!(```````"\````
M``````8``````````@`````````"`````````&X```#^__]O`@`````````P
M$P```````#`3````````@``````````'`````0````@`````````````````
M``!]````!`````(`````````L!,```````"P$P```````*@&````````!@``
M```````(`````````!@`````````AP````$````&```````````@````````
M`"`````````;````````````````````!````````````````````(T````!
M````!@`````````@(````````"`@````````$3P``````````````````!``
M``````````````````"3`````0````8`````````-%P````````T7```````
M``T````````````````````$````````````````````F0````$````"````
M``````!@`````````&````````!P/P``````````````````$```````````
M`````````*$````!`````@````````!PGP```````'"?````````W```````
M``````````````0```````````````````"O`````0````(`````````4*``
M``````!0H````````!`&```````````````````(````````````````````
MN0````X````#`````````/"[````````\*L````````(````````````````
M````"``````````(`````````,4````/`````P````````#XNP```````/BK
M````````"`````````````````````@`````````"`````````#1````!@``
M``,``````````+P`````````K````````-`!````````!P`````````(````
M`````!``````````V@````$````#`````````-"]````````T*T````````P
M`@``````````````````"``````````(`````````-\````!`````P``````
M````P`````````"P````````(`````````````````````@`````````````
M``````#E````"`````,`````````(,`````````@L````````$`0````````
M```````````@````````````````````Z@````$````P````````````````
M````(+`````````2`````````````````````0`````````!``````````$`
M```#`````````````````````````#*P````````\P``````````````````
1``$`````````````````````
